# Data models for Notion API

[![PyPI version](https://img.shields.io/pypi/v/pydantic-api-models-notion)](https://pypi.org/project/pydantic-api-models-notion/)

Pydantic data model for [Notion](https://www.notion.so/).


Install via:
```sh
pip install pydantic-api-models-notion
```

## Development

This repository uses [devenv](https://devenv.sh/). Devenv and enabled direnv will give you the best developer experience.

## Releasing

Create a new release [here](https://github.com/stevieflyer/pydantic-api-models-notion/releases/new).
Choose a semver-style tag (i.e. `X.X.X`). Make sure the tag matches the version in `pyproject.toml`.
